#if 0

#include "osl/move_generator/dropAoundKing8.cc"
#include "osl/move_generator/pieceOnBoard.h"
#include "osl/move_generator/pieceOnBoard.tcc"
#include "osl/move_generator/drop.h"
#include "osl/move_generator/drop.tcc"
#include "osl/move_action/toAroundKing8Filter.h"

namespace osl
{
  namespace move_generator
  {
    template <Player P>
    struct DropAroundKing8
    {
      template <class Action>
      static void generate(const SimpleState& state, Action& action)
      {
	//
	Drop<SimpleState, Action>::template generateMoves <P>(state, action);
	move_action::ToAroundKing8Filter<P, SimpleState, Action> action_filtered(state, action);
	PieceOnBoardType<P, KING>::template
 	  generate(state, state.kingPiece<P>(), action_filtered);
      }
    };
  }
} // namespace osl

#endif /* _GENERATE_DROP_AROUND_KING8_H */
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
